@@ -32,6 +32,7 @@ from pyatspi.hypertext import *
 from pyatspi.image import *
 from pyatspi.selection import *
 from pyatspi.table import *
+from pyatspi.tablecell import *
 from pyatspi.value import *
 from pyatspi.appevent import *
 from pyatspi.interface import *
@@ -127,6 +128,7 @@ Atspi.Accessible.getState = Atspi.Accessible.get_state_set
 del Atspi.Accessible.children
 Atspi.Accessible.description = property(fget=Atspi.Accessible.get_description)
 Atspi.Accessible.objectLocale = property(fget=Atspi.Accessible.get_object_locale)
+Atspi.Accessible.accessibleId = property(fget=Atspi.Accessible.get_accessible_id)
 Atspi.Accessible.name = property(fget=Atspi.Accessible.get_name)
 Atspi.Accessible.isEqual = lambda a,b: a == b
 Atspi.Accessible.parent = property(fget=Atspi.Accessible.get_parent)
@@ -148,6 +150,7 @@ Atspi.Accessible.queryHypertext = lambda x: Hypertext(getInterface(Atspi.Accessi
 Atspi.Accessible.queryImage = lambda x: Image(getInterface(Atspi.Accessible.get_image_iface, x))
 Atspi.Accessible.querySelection = lambda x: Selection(getInterface(Atspi.Accessible.get_selection_iface, x))
 Atspi.Accessible.queryTable = lambda x: Table(getInterface(Atspi.Accessible.get_table_iface, x))
+Atspi.Accessible.queryTableCell = lambda x: TableCell(getInterface(Atspi.Accessible.get_table_cell, x))
 Atspi.Accessible.queryText = lambda x: Text(getInterface(Atspi.Accessible.get_text_iface, x))
 Atspi.Accessible.queryValue = lambda x: Value(getInterface(Atspi.Accessible.get_value_iface, x))
 
@@ -162,6 +165,7 @@ interface.queryHypertext = lambda x: Hypertext(getInterface(Atspi.Accessible.get
 interface.queryImage = lambda x: Image(getInterface(Atspi.Accessible.get_image, x.obj))
 interface.querySelection = lambda x: Selection(getInterface(Atspi.Accessible.get_selection, x.obj))
 interface.queryTable = lambda x: Table(getInterface(Atspi.Accessible.get_table, x.obj))
+interface.queryTableCell = lambda x: Table(getInterface(Atspi.Accessible.get_table_cell, x.obj))
 interface.queryText = lambda x: Text(getInterface(Atspi.Accessible.get_text, x.obj))
 interface.queryValue = lambda x: Value(getInterface(Atspi.Accessible.get_value, x.obj))
 
@@ -208,6 +212,10 @@ RELATION_POPUP_FOR = Atspi.RelationType.POPUP_FOR
 RELATION_PARENT_WINDOW_OF = Atspi.RelationType.PARENT_WINDOW_OF
 RELATION_DESCRIPTION_FOR = Atspi.RelationType.DESCRIPTION_FOR
 RELATION_DESCRIBED_BY = Atspi.RelationType.DESCRIBED_BY
+RELATION_DETAILS = Atspi.RelationType.DETAILS
+RELATION_DETAILS_FOR = Atspi.RelationType.DETAILS_FOR
+RELATION_ERROR_MESSAGE = Atspi.RelationType.ERROR_MESSAGE
+RELATION_ERROR_FOR = Atspi.RelationType.ERROR_FOR
 
 # Build a dictionary mapping relation values to names based on the prefix of the enum constants.
 
@@ -238,6 +246,8 @@ KEY_PRESSRELEASE = Atspi.KeySynthType.PRESSRELEASE
 KEY_RELEASE = Atspi.KeySynthType.RELEASE
 KEY_STRING = Atspi.KeySynthType.STRING
 KEY_SYM = Atspi.KeySynthType.SYM
+KEY_LOCKMODIFIERS = Atspi.KeySynthType.LOCKMODIFIERS
+KEY_UNLOCKMODIFIERS = Atspi.KeySynthType.UNLOCKMODIFIERS
 
 ### cache ###
 cache = Atspi.Cache
