@@ -67,6 +67,7 @@ EVENT_TREE = {
      'document:reload',
      'document:load-stopped',
      'document:attributes-changed'
+     'document:page-changed'
      ],
   'object': 
     ['object:property-change',
@@ -110,6 +111,8 @@ EVENT_TREE = {
     'object:children-changed:remove'],
   'object:state-changed' :
     ['object:state-changed:'],
+  'object:text-reading-position' :
+      ['object:text-reading-position:'],
   'mouse' :
     ['mouse:abs',
     'mouse:rel',
